#!/usr/bin/env python3

import copy
import json
import subprocess
import sys


'''
=========================================
Проверь тип / и его предков, начиная с самого старшего.
Если хотя бы 1 из них имеет 'type': 'crypt', то корневая фс зашифрована
и на неё можно класть пароль.
В установщике / смонтирован в /mnt/destination
=========================================
Check the type of / and its ancestors, starting with the oldest.
If at least 1 of them has 'type': 'crypt', then the root fs is encrypted
and you can put a password on it.
In installer / mounted in /mnt/destination
=========================================
'''


def traverse_blkdev(f, obj, parents):
	ret = []
	result = f(obj, parents)
	if result is not None:
		ret.append(result)
	ancestry = copy.deepcopy(parents or [])
	ancestry += [obj]
	for child in obj.get('children', []):
		ret += traverse_blkdev(f, child, ancestry)
	return ret


def find_rootfs(obj, parents):
	mountpoint = obj.get('mountpoint', '')
	if mountpoint == '/mnt/destination':
            return ([{'name': p.get('name'), 'type': p.get('type')} for p in parents] + [{'name': obj.get('name'), 'type': obj.get('type')}])


def run_lsblk():
	s = subprocess.check_output(['lsblk', '--json'], encoding='utf-8')
	return json.loads(s)['blockdevices']


def find_cryptroot(lsblk):
	rootdev = []
	for dev in lsblk():
		rootdev += traverse_blkdev(find_rootfs, dev, [])
	return rootdev


if __name__ == '__main__':
	out = find_cryptroot(run_lsblk)[0]
	for dev in out:
		if 'crypt' == dev.get('type'):
# root fs encrypted - it is possible to write a password
			sys.exit(0)
	else:
# root fs is not encrypted - do not write the password
		sys.exit(1)

